@@ -13,7 +13,7 @@ def dialect_dispatch(postgresql=None, sqlite=None):
             dialect_name = "sqlite"
 
         dispatcher = dispatchers.get(dialect_name)
-        if dispatcher is None:
+        if dispatcher is None:  # pragma: no cover
             raise NotImplementedError(
                 f"'{dialect_name}' is not yet supported for this operation."
             )
